-- Cerradon Source
-- Created by Raptr Studios
-- http://raptrstudios.weebly.com/
-- Remember to ask before using any of this code!

cerradon = {
	version = '0.1.7 Demo',
}

function gamestate_manage()
	if gamestate == 'startup' then
		love.graphics.setFont(default)
		love.graphics.print('Loading Cerradon...', 620, 585)
		gamestate = 'menu'
	elseif gamestate == 'menu' then
		love.graphics.draw( clouds, 0, 0, 0, 1, 1, 0 )
		love.graphics.draw( logo, 250, 10, 0, 1, 1, 0 )
		draw_mainMenu()
		love.graphics.print('v'..cerradon.version, 0, 587)
		love.graphics.print('Raptr Studios', 670, 587)
	elseif gamestate == 'world' then
		cam:draw(function()
			love.graphics.draw( clouds, 0, 0, 0, 1, 1, 0 )
			draw_map()
			draw_player()
		end)
		if shop_toggle then
			love.graphics.draw( shop_menu, 50, 50, 0, 1, 1, 0 )
			draw_shopMenu()
		end
	end
end

function draw_player()
	if player_object.facing == 'idle' then
		love.graphics.draw( idle_player, player_object.x, player_object.y )
	end
	if player_object.facing == 'left' and love.keyboard.isDown('a') then
		walkLeft:draw(player_object.x, player_object.y)
		llama_face = 'left'
	end
	if player_object.facing == 'right' and love.keyboard.isDown('d') then
		walkRight:draw(player_object.x, player_object.y)
		llama_face = 'right'
	end
	if love.keyboard.isDown('w') then
		if player_object.y_velocity == 0 then -- we're probably on the ground, let's jump
            player_object.y_velocity = jump_height
        end
	end
	player_object.facing = 'idle'
end

function anim()
	walkLeft = newAnimation(player_object.player_left, 16, 16, 0.2, 0)
    walkRight = newAnimation(player_object.player_right, 16, 16, 0.2, 0)
end

function ui()
	love.graphics.setFont(default)
	love.graphics.print('FPS: ' ..tostring(love.timer.getFPS( )), 715, 0)
	love.graphics.print('$' ..math.floor(player_currency), 400, 0)
	if reg_notif == true then
		ui_notify('REGISTER: $' ..tostring(math.floor(reg_table.cash_hold)))
	end
	if shop_notif == true then
		ui_notify('SHOP, PRESS \'e\'')
	else
		shop_toggle = false
	end
	reg_notif = false
	shop_notif = false
	init_special()
end

function keys(dt)
	if isSpecial == true then
		timer_update(dt)
	end
	
	if love.keyboard.isDown('q') then
		love.event.quit( )
	end
	
	if love.keyboard.isDown('s') then
		isSpecial = true
	end
	
	if love.keyboard.isDown('kp+') then
		if gamestate == 'world' then
			scale_value = scale_value + 0.1
			cam:setScale(scale_value)
		end
	end
	
	if love.keyboard.isDown('kp-') then
		if gamestate == 'world' then
			scale_value = scale_value - 0.1
			cam:setScale(scale_value)
		end
	end
	
	if love.keyboard.isDown('kp*') then
		if gamestate == 'world' then
			scale_value = 2.0
			cam:setScale(scale_value)
		end
	end
	
	if love.keyboard.isDown(']') then
		reg_table.cash_hold = reg_table.cash_hold + 1
	end
	
	if love.keyboard.isDown('[') then
		reg_table.cash_hold = reg_table.cash_hold - 1
	end
	
	if love.keyboard.isDown('.') then
		player_currency = player_currency + 1
	end
	
	if love.keyboard.isDown(',') then
		player_currency = player_currency - 1
	end
	
	if love.keyboard.isDown('m') then
		gamestate = 'menu'
	end
end

function check_system()
	errortitle = "Shader support is required for the game to run"
	errormessage = "This system is below the minimum system requirements for the game.\nIf your graphics drivers aren't up-to-date, try updating them and running the game again."

	if not love.graphics.isSupported("shader") then
		love.window.showMessageBox(errortitle, errormessage, "error")
		love.event.push('quit')
	end
end

function check_fps()
	errortitle_2 = "FPS is to low for the game to run"
	errormessage_2 = "This system is below the minimum fps required for the game.\nIf your graphics drivers aren't up-to-date, try updating them and running the game again.\nThe game will still run, but it might crash."

	if love.timer.getFPS() < 10 then
		love.window.showMessageBox(errortitle_2, errormessage_2, "error")
	end
end

function interactives_setup()
	reg_table = {
		cash_hold = 0,
		tooltip = '',
	}
	
	shop_table = {
		truck = {
			name = 'Jungle Truck',
			price = '100',
		},
		
		robot = {
			name = 'Jungle Truck',
			price = '100',
		},
	}
end

function register_update(dt)
	reg_table.cash_hold = reg_table.cash_hold + 0.1 * dt
end

-- ALL COORDS
reg_coords = {
	x = 0,
	y = 0,
}

grass_coords = {
	x = 0,
	y = 0,
}

stone_coords = {
	x = 0,
	y = 0,
}

dirt_coords = {
	x = 0,
	y = 0,
}

robot_coords = {
	x = 0,
	y = 0,
}

shop_coords = {
	x = 0,
	y = 0,
}

function check_interactives()
	calculate_collisions(player_object.x, player_object.y, reg_coords.x, reg_coords.y, 16, 16, function()
		reg_notif = true
		if love.keyboard.isDown('e') then
			if math.floor(reg_table.cash_hold) > 0 then
				player_currency = player_currency + math.floor(reg_table.cash_hold)
				reg_table.cash_hold = 0
			end
		end
	end)
	
	calculate_collisions(player_object.x, player_object.y, shop_coords.x, shop_coords.y, 16, 16, function()
		shop_notif = true
	end)
end

shop_toggle = false

function shop_keyboard(key)
	calculate_collisions(player_object.x, player_object.y, shop_coords.x, shop_coords.y, 16, 16, function()
		if key == 'e' then
			if shop_toggle == false then
				shop_toggle = true
			else
				shop_toggle = false
			end
		end
	end)
end

function ui_notify(notify_text)
	love.graphics.print(notify_text, 100, 0)
end

function check_for_cheat()
	if tonumber(player_currency) >= 100000000 then
		love.window.showMessageBox('Cheater!', 'Due to cheating you may no longer play cerradon.\nWe don\'t like cheaters!\nAmount you\'ve cheated: ' ..player_currency, "error")
		love.event.push('quit')
	end
end